import typer
from pathlib import Path
from zona import builder, server

app = typer.Typer()


@app.command()
def build(in_dir: str | None = None, out_dir: str | None = None):
    if in_dir is None:
        in_dir = "."
    if out_dir is None:
        out_dir = "public"
    items = builder.discover(Path(in_dir), Path(out_dir))
    builder.build(Path(in_dir), items)


@app.command()
def serve(dir: Path = Path("public")):
    if not dir.exists():
        raise typer.BadParameter(f"Directory {dir} does not exist.")
    typer.echo(f"Serving files from {dir}")
    server.serve(dir)


@app.command()
def init():
    # init will populate the current directory with
    # the required folders and their default values
    print("Init logic here...")


def main():
    app()
