from pathlib import Path
from enum import Enum
from datetime import date
from dataclasses import dataclass, field


@dataclass
class Metadata:
    title: str
    date: date
    description: str | None
    style: str | None = "/static/style.css"
    header: bool = True
    footer: bool = True
    template: str = "page.html"


class ItemType(Enum):
    MARKDOWN = "markdown"
    HTML = "html"
    IMAGE = "image"


@dataclass
class Item:
    source: Path
    destination: Path
    url: str  # relative to site root
    metadata: Metadata | None = None  # frontmatter
    content: str | None = None
    type: ItemType | None = None
    copy: bool = True


@dataclass
class BuildCtx:
    root: Path
    base: Path
    item_map: dict[Path, Item] = field(default_factory=dict)
